<?php


namespace FiloBlu\Pos\Controller\Adminhtml\Posmode;

class Enable extends \Magento\Backend\App\Action
{

    /**
     * @var \Magento\Store\Model\StoreManagerInterface
     */
    public $storeManager;

    /**
     * @var \Magento\Framework\Url
     */
    public $url;

    /**
     * @var \FiloBlu\Pos\Helper\Pos
     */
    public $posHelper;

    /**
     * Enable constructor.
     * @param \Magento\Backend\App\Action\Context $context
     * @param \Magento\Store\Model\StoreManagerInterface $storeManager
     * @param \Magento\Framework\Url $url
     * @param \FiloBlu\Pos\Helper\Pos $posHelper
     */
    public function __construct(
        \Magento\Backend\App\Action\Context $context,
        \Magento\Store\Model\StoreManagerInterface $storeManager,
        \Magento\Framework\Url $url,
        \FiloBlu\Pos\Helper\Pos $posHelper
    ) {
        $this->storeManager = $storeManager;
        $this->url = $url;
        $this->posHelper = $posHelper;
        parent::__construct($context);
    }

    /**
     * Execute view action
     *
     * @return \Magento\Framework\Controller\ResultInterface
     */
    public function execute()
    {
        $store = $this->storeManager->getDefaultStoreView();
        $url = $this->url->setScope($store);

        if ($this->getRequest()->getParam('device') != NULL) {
            $deviceIndex = $this->getRequest()->getParam('device');
            if (is_null($deviceIndex)) { //non credo che ci entrerà mai
                $this->messageManager->addError('Error: Could not understand which device to enable');
                $this->getResponse()->setRedirect(
                    $this->getUrl('adminhtml/system_config/edit/section/filoblu_pos')
                );
                return;
            }

            $deviceHash = $this->posHelper->retrieveDeviceHashByIndex($deviceIndex);
            if ($deviceHash == FALSE) {
                $this->messageManager->addError('Could not understand which device to enable');
                $this->getResponse()->setRedirect(
                    $this->getUrl('adminhtml/system_config/edit/section/filoblu_pos')
                );
                return;
            }

            $redirectUrl = $url->getUrl(
                'posmode/posmode/enable',
                ['_nosid' => true, 'device' => $deviceHash]
            );
        } elseif ($this->getRequest()->getParam('visibility') != NULL) {
            $enableRequest = $this->getRequest()->getParam('visibility');
            if ($enableRequest == 1) {
                $isGoingToEnable = 1;
            } else {
                $isGoingToEnable = 0;
            }
            $redirectUrl = $url->getUrl(
                'posmode/posmode/enable',
                ['_nosid' => true, 'visibility' => $isGoingToEnable]
            );
        }

        $this->getResponse()->setRedirect(
            $redirectUrl
        );

        return;
    }
}